% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/FLM1.R
\name{FLM1}
\alias{FLM1}
\title{Functional Linear Models New}
\usage{
FLM1(Y, X, XTest = NULL, optnsListY = NULL, optnsListX = NULL, nPerm = NULL)
}
\arguments{
\item{Y}{Either an \emph{n}-dimensional vector whose elements consist of scalar responses, or a list which contains functional responses in the form of a list LY and the time points LT at which they are observed (i.e., list(Ly = LY,Lt = LT)).}

\item{X}{A list of either (1) lists which contains the observed functional predictors list Lxj and the time points list Ltj at which they are observed. It needs to be of the form \code{list(list(Ly = Lx1,Lt = Lxt1),list(Ly = Lx2,Lt = Lxt2),...)}; (2) a matrix containing one or more scalar covariates; or (3) a mix of (1) and (2), in which case the scalar covariates must come after the functional ones(TODO).}

\item{XTest}{A list which contains the values of functional predictors for a held-out testing set.}

\item{optnsListY}{A list of options control parameters for the response specified by \code{list(name=value)}. See `Details' in  \code{FPCA}.}

\item{optnsListX}{Either (1) A list of options control parameters for the predictors specified by \code{list(name=value)}; or (2) A list of list of options, e.g. \code{list(list(name1=value1), list(name2=value2))}. See `Details' in  \code{FPCA}.}

\item{nPerm}{If this argument is specified, perform a permutation test to obtain the (global) p-value for the test of regression relationship between X and Y. Recommend to set to 1000 or larger if specified.}
}
\value{
A list of the following:
\item{alpha}{A length-one numeric if the response Y is scalar. Or a vector of \code{length(workGridY)} of the fitted constant alpha(t) in the linear model if Y is functional.}
\item{betaList}{A list of fitted beta(s) vectors, one entry per functional predictor and one entry for all scalar predictors, if Y is scalar. Each of dimension \code{length(workGridX[[j]])}.

Or a list of fitted beta(s,t) matrices, one per predictor, if Y is functional. Each of dimension \code{length(workGridX[[j]])} times \code{length(workGridY)}.
}
\item{R2}{The functional R2}
\item{pv}{Permutation p-value based on the functional R2. NA if \code{nPerm} is \code{NULL}}
\item{yHat}{A length n vector if Y is scalar. 

Or an n by \code{length(workGridY)} matrix of fitted Y's from the model if Y is functional.}

\item{yPred}{Same as YHat if XTest is not provided. 

Or a length \code{length(XTest[[1]]$Ly)} vector of predicted Y's if Y is scalar.

Or a \code{length(XTest[[1]]$Ly)} by \code{length(workGridY)} matrix of predicted Y's if Y is functional.}


\item{estXi}{A list of n by k_j matrices of estimated functional principal component scores of predictors, where k_j is the number of eigenfunctions selected for each predictor.}
\item{testXi}{A list of n by k_j matrices of estimated functional principal component scores of predictors in XTest, with eigenfunctions fitted only with X.}
\item{lambdaX}{A length sum_j k_j vector of estimated eigenvalues for predictors.}
\item{workGridX}{A list of vectors, each is a working grid for a predictor.}
\item{optnsListX}{A list of list of options actually used by the FPCA for the predictor functions}
\item{optnsListY}{A list of options actually used by the FPCA for the response functions}
\item{phiY}{A \code{length(workGridY)} by k_y the estimated eigenfunctions of Y's, where k_y is number of eigenfunctions selected for Y. NULL if Y is scalar.}
\item{workGridY}{A vector of working grid of the response Y's. NULL if Y is scalar}
\item{muY}{The mean or the mean function of the response}
}
\description{
Functional linear models for scalar or functional responses and functional predictors.
}
